# emucore-direct

This package is the companion client to Quantum Computing Inc.'s (QCi) EmuCore FPGA based reservoir computer. This device can be used to solve a variety of problems related to serial data structures including time series prediction, image recognition, and text classification. It is fast, affordable, energy-efficient, and brings the power of a standalone edge computing to your desktop. This package provides a lightweight communication interface with the EmuCore device.



## Additional Resources

- [Package documentation](https://quantumcomputinginc.com/learn/reference-documentation/emucore-direct)
- [EmuCore Device Info](https://quantumcomputinginc.com/products/emucore)
- [QCi website](https://quantumcomputinginc.com/)